/****************************************************************************
** Meta object code from reading C++ file 'imapsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "imapsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imapsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN34OrgKdeAkonadiImapSettingsInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeAkonadiImapSettingsInterface::qt_create_metaobjectdata<qt_meta_tag_ZN34OrgKdeAkonadiImapSettingsInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeAkonadiImapSettingsInterface",
        "accountIdentity",
        "QDBusPendingReply<int>",
        "",
        "alternateAuthentication",
        "authentication",
        "automaticExpungeEnabled",
        "QDBusPendingReply<bool>",
        "disconnectedModeEnabled",
        "idleRidPath",
        "QDBusPendingReply<QStringList>",
        "imapPort",
        "imapServer",
        "QDBusPendingReply<QString>",
        "intervalCheckEnabled",
        "intervalCheckTime",
        "knownMailBoxes",
        "overrideEncryption",
        "retrieveMetadataOnFolderListing",
        "safety",
        "save",
        "QDBusPendingReply<>",
        "sessionTimeout",
        "setAccountIdentity",
        "in0",
        "setAlternateAuthentication",
        "setAuthentication",
        "setAutomaticExpungeEnabled",
        "setDisconnectedModeEnabled",
        "setIdleRidPath",
        "setImapPort",
        "setImapServer",
        "setIntervalCheckEnabled",
        "setIntervalCheckTime",
        "setKnownMailBoxes",
        "setOverrideEncryption",
        "setRetrieveMetadataOnFolderListing",
        "setSafety",
        "setSessionTimeout",
        "setSieveAlternateUrl",
        "setSieveCustomAuthentification",
        "setSieveCustomUsername",
        "setSievePort",
        "setSieveReuseConfig",
        "setSieveSupport",
        "setSieveVacationFilename",
        "setSubscriptionEnabled",
        "setTrashCollection",
        "setTrashCollectionMigrated",
        "setUseDefaultIdentity",
        "setUserName",
        "sieveAlternateUrl",
        "sieveCustomAuthentification",
        "sieveCustomUsername",
        "sievePort",
        "sieveReuseConfig",
        "sieveSupport",
        "sieveVacationFilename",
        "subscriptionEnabled",
        "trashCollection",
        "QDBusPendingReply<qlonglong>",
        "trashCollectionMigrated",
        "useDefaultIdentity",
        "userName"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'accountIdentity'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'alternateAuthentication'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(4, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'authentication'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(5, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'automaticExpungeEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(6, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'disconnectedModeEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(8, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'idleRidPath'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(9, 3, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'imapPort'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(11, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'imapServer'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(12, 3, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'intervalCheckEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(14, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'intervalCheckTime'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(15, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'knownMailBoxes'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(16, 3, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'overrideEncryption'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(17, 3, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'retrieveMetadataOnFolderListing'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(18, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'safety'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(19, 3, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'save'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(20, 3, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'sessionTimeout'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(22, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'setAccountIdentity'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(23, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setAlternateAuthentication'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(25, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setAuthentication'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(26, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setAutomaticExpungeEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(27, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setDisconnectedModeEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(28, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setIdleRidPath'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(29, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QStringList, 24 },
        }}),
        // Slot 'setImapPort'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(30, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setImapServer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(31, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setIntervalCheckEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(32, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setIntervalCheckTime'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(33, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setKnownMailBoxes'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(34, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QStringList, 24 },
        }}),
        // Slot 'setOverrideEncryption'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(35, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setRetrieveMetadataOnFolderListing'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(36, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setSafety'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(37, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setSessionTimeout'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(38, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setSieveAlternateUrl'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(39, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setSieveCustomAuthentification'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(40, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setSieveCustomUsername'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(41, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setSievePort'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(42, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setSieveReuseConfig'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(43, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setSieveSupport'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(44, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setSieveVacationFilename'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(45, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setSubscriptionEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(46, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setTrashCollection'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong)>(47, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::LongLong, 24 },
        }}),
        // Slot 'setTrashCollectionMigrated'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(48, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setUseDefaultIdentity'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(49, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setUserName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(50, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'sieveAlternateUrl'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(51, 3, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'sieveCustomAuthentification'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(52, 3, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'sieveCustomUsername'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(53, 3, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'sievePort'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(54, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'sieveReuseConfig'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(55, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'sieveSupport'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(56, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'sieveVacationFilename'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(57, 3, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'subscriptionEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(58, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'trashCollection'
        QtMocHelpers::SlotData<QDBusPendingReply<qlonglong>()>(59, 3, QMC::AccessPublic, 0x80000000 | 60),
        // Slot 'trashCollectionMigrated'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(61, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'useDefaultIdentity'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(62, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'userName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(63, 3, QMC::AccessPublic, 0x80000000 | 13),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeAkonadiImapSettingsInterface, qt_meta_tag_ZN34OrgKdeAkonadiImapSettingsInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeAkonadiImapSettingsInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgKdeAkonadiImapSettingsInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgKdeAkonadiImapSettingsInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN34OrgKdeAkonadiImapSettingsInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeAkonadiImapSettingsInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeAkonadiImapSettingsInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<int> _r = _t->accountIdentity();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<int> _r = _t->alternateAuthentication();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<int> _r = _t->authentication();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<bool> _r = _t->automaticExpungeEnabled();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<bool> _r = _t->disconnectedModeEnabled();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QStringList> _r = _t->idleRidPath();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<int> _r = _t->imapPort();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QString> _r = _t->imapServer();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->intervalCheckEnabled();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<int> _r = _t->intervalCheckTime();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QStringList> _r = _t->knownMailBoxes();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QString> _r = _t->overrideEncryption();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<bool> _r = _t->retrieveMetadataOnFolderListing();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->safety();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->save();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<int> _r = _t->sessionTimeout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->setAccountIdentity((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->setAlternateAuthentication((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->setAuthentication((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->setAutomaticExpungeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->setDisconnectedModeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->setIdleRidPath((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->setImapPort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->setImapServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->setIntervalCheckEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->setIntervalCheckTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->setKnownMailBoxes((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->setOverrideEncryption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<> _r = _t->setRetrieveMetadataOnFolderListing((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<> _r = _t->setSafety((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<> _r = _t->setSessionTimeout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<> _r = _t->setSieveAlternateUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<> _r = _t->setSieveCustomAuthentification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<> _r = _t->setSieveCustomUsername((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusPendingReply<> _r = _t->setSievePort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<> _r = _t->setSieveReuseConfig((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusPendingReply<> _r = _t->setSieveSupport((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 37: { QDBusPendingReply<> _r = _t->setSieveVacationFilename((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: { QDBusPendingReply<> _r = _t->setSubscriptionEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<> _r = _t->setTrashCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<> _r = _t->setTrashCollectionMigrated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<> _r = _t->setUseDefaultIdentity((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<> _r = _t->setUserName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 43: { QDBusPendingReply<QString> _r = _t->sieveAlternateUrl();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 44: { QDBusPendingReply<QString> _r = _t->sieveCustomAuthentification();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 45: { QDBusPendingReply<QString> _r = _t->sieveCustomUsername();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDBusPendingReply<int> _r = _t->sievePort();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 47: { QDBusPendingReply<bool> _r = _t->sieveReuseConfig();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 48: { QDBusPendingReply<bool> _r = _t->sieveSupport();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 49: { QDBusPendingReply<QString> _r = _t->sieveVacationFilename();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 50: { QDBusPendingReply<bool> _r = _t->subscriptionEnabled();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 51: { QDBusPendingReply<qlonglong> _r = _t->trashCollection();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<qlonglong>*>(_a[0]) = std::move(_r); }  break;
        case 52: { QDBusPendingReply<bool> _r = _t->trashCollectionMigrated();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 53: { QDBusPendingReply<bool> _r = _t->useDefaultIdentity();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 54: { QDBusPendingReply<QString> _r = _t->userName();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *OrgKdeAkonadiImapSettingsInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeAkonadiImapSettingsInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgKdeAkonadiImapSettingsInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeAkonadiImapSettingsInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 55)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 55;
    }
    return _id;
}
QT_WARNING_POP
