// This file is generated by kconfig_compiler_kf6 from specialmailcollections.kcfg.
// All changes you do to this file will be lost.
#ifndef AKONADI_SPECIALMAILCOLLECTIONSSETTINGS_H
#define AKONADI_SPECIALMAILCOLLECTIONSSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace Akonadi {

class SpecialMailCollectionsSettings : public KConfigSkeleton
{
  public:

    static SpecialMailCollectionsSettings *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~SpecialMailCollectionsSettings() override;

    /**
      Set Id of the resource containing the default special collections.
    */
    static
    void setDefaultResourceId( const QString & v )
    {
      if (!self()->isDefaultResourceIdImmutable())
        self()->mDefaultResourceId = v;
    }

    /**
      Get Id of the resource containing the default special collections.
    */
    static
    QString defaultResourceId()
    {
      return self()->mDefaultResourceId;
    }

    /**
      Is Id of the resource containing the default special collections. Immutable
    */
    static
    bool isDefaultResourceIdImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DefaultResourceId" ) );
    }

    /**
      Get Item object corresponding to DefaultResourceId()
    */
    ItemString *defaultResourceIdItem()
    {
      return mDefaultResourceIdItem;
    }

  protected:
    SpecialMailCollectionsSettings(KSharedConfig::Ptr config);
    friend class SpecialMailCollectionsSettingsHelper;


    // SpecialCollections
    QString mDefaultResourceId;

  private:
    ItemString *mDefaultResourceIdItem;
};

}

#endif

