/****************************************************************************
** Meta object code from reading C++ file 'messagestatus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../akonadi-mime-26.07.80/src/messagestatus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'messagestatus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi13MessageStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::MessageStatus::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi13MessageStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::MessageStatus",
        "isOfUnknownStatus",
        "isRead",
        "isDeleted",
        "isReplied",
        "isForwarded",
        "isQueued",
        "isSent",
        "isImportant",
        "isWatched",
        "isIgnored",
        "isSpam",
        "isHam",
        "isToAct",
        "hasAttachment",
        "hasInvitation",
        "isEncrypted",
        "isSigned",
        "hasError"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isOfUnknownStatus'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isRead'
        QtMocHelpers::PropertyData<bool>(2, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isDeleted'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isReplied'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isForwarded'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isQueued'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isSent'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isImportant'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isWatched'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isIgnored'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isSpam'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isHam'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isToAct'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasAttachment'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasInvitation'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isEncrypted'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isSigned'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasError'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MessageStatus, qt_meta_tag_ZN7Akonadi13MessageStatusE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::MessageStatus::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi13MessageStatusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi13MessageStatusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi13MessageStatusE_t>.metaTypes,
    nullptr
} };

void Akonadi::MessageStatus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<MessageStatus *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isOfUnknownStatus(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isRead(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isDeleted(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isReplied(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isForwarded(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isQueued(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isSent(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isImportant(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isWatched(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isIgnored(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isSpam(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isHam(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isToAct(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->hasAttachment(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->hasInvitation(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isEncrypted(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isSigned(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->hasError(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setRead(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setDeleted(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setReplied(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setForwarded(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setQueued(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setSent(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setImportant(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setWatched(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setIgnored(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setSpam(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setHam(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setToAct(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setHasAttachment(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setHasInvitation(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setEncrypted(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setSigned(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setHasError(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
